@@ -1,12 +1,13 @@
-from bluer_sbc.README.designs.cheshmak import marquee as cheshmak_marquee
-from bluer_sbc.README.designs.blue_bracket import items as blue_bracket_items
-from bluer_sbc.README.designs.swallow import marquee as swallow_marquee
-from bluer_sbc.README.designs.swallow_head import marquee as swallow_head_marquee
-from bluer_sbc.README.designs.bryce import marquee as bryce_marquee
-from bluer_sbc.README.designs.nafha import marquee as nafha_marquee
-from bluer_sbc.README.designs.shelter import marquee as shelter_marquee
 from bluer_sbc.README.designs.adapter_bus import marquee as adapter_bus_marquee
 from bluer_sbc.README.designs.battery_bus import marquee as battery_bus_marquee
+from bluer_sbc.README.designs.blue_bracket import items as blue_bracket_items
+from bluer_sbc.README.designs.bryce import marquee as bryce_marquee
+from bluer_sbc.README.designs.nafha import marquee as nafha_marquee
+from bluer_sbc.README.designs.cheshmak import marquee as cheshmak_marquee
+from bluer_sbc.README.designs.regulated_bus import marquee as regulated_bus_marquee
+from bluer_sbc.README.designs.shelter import marquee as shelter_marquee
+from bluer_sbc.README.designs.swallow import marquee as swallow_marquee
+from bluer_sbc.README.designs.swallow_head import marquee as swallow_head_marquee
 from bluer_sbc.README.designs.ultrasonic_sensor_tester import (
     marquee as ultrasonic_sensor_tester_marquee,
 )
@@ -17,6 +18,7 @@ docs = [
         "items": []
         + swallow_head_marquee
         + swallow_marquee
+        + regulated_bus_marquee
         + battery_bus_marquee
         + adapter_bus_marquee
         + ultrasonic_sensor_tester_marquee
